# airflow-config

[Apache Airflow](https://airflow.apache.org) utilities for for configuration of many DAGs and DAG environments

[![Build Status](https://github.com/timkpaine/airflow-config/actions/workflows/build.yml/badge.svg)](https://github.com/timkpaine/airflow-config/actions?query=workflow%3A%22Build+Status%22)
[![codecov](https://codecov.io/gh/timkpaine/airflow-config/branch/main/graph/badge.svg)](https://codecov.io/gh/timkpaine/airflow-config)
[![License](https://img.shields.io/github/license/timkpaine/airflow-config)](https://github.com/timkpaine/airflow-config)
[![PyPI](https://img.shields.io/pypi/v/airflow-config.svg)](https://pypi.python.org/pypi/airflow-config)
